@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.war.stub;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.war.stub;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,29 +16,24 @@ package org.apache.maven.plugins.war.stub;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.war.stub;
 
 import java.io.File;
 
-public class PARArtifactStub
-    extends AbstractArtifactStub
-{
-    public PARArtifactStub( String _basedir )
-    {
-        super( _basedir );
+public class PARArtifactStub extends AbstractArtifactStub {
+    public PARArtifactStub(String _basedir) {
+        super(_basedir);
     }
 
-    public String getType()
-    {
+    public String getType() {
         return "par";
     }
 
-    public String getArtifactId()
-    {
+    public String getArtifactId() {
         return "parartifact";
     }
 
-    public File getFile()
-    {
-        return new File( basedir, "/target/test-classes/unit/sample_wars/sample.par" );
+    public File getFile() {
+        return new File(basedir, "/target/test-classes/unit/sample_wars/sample.par");
     }
 }
