@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.war.stub;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.war.stub;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,40 +16,34 @@ package org.apache.maven.plugins.war.stub;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.war.stub;
 
 import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.maven.model.Resource;
 
-public class ResourceStub
-    extends Resource
-{
+public class ResourceStub extends Resource {
     /**
-     * 
+     *
      */
     private static final long serialVersionUID = 7685068931840967662L;
 
     private String directory;
 
-    public List<String> getIncludes()
-    {
+    public List<String> getIncludes() {
         return new ArrayList<>();
     }
 
-    public List<String> getExcludes()
-    {
+    public List<String> getExcludes() {
         return new ArrayList<>();
     }
 
-    public void setDirectory( String _directory )
-    {
+    public void setDirectory(String _directory) {
         directory = _directory;
     }
 
-    public String getDirectory()
-    {
+    public String getDirectory() {
         return directory;
     }
-
 }
